@@ -26,7 +26,7 @@ class ExceptionMiddleware(MiddlewareMixin):
 			"traceback":traceback.format_exc() 
 		}
 		
-		apio_url_exception = "http://localhost:8000/remote_data_exception"
+		apio_url_exception = "https://apio.in/remote_data_exception"
 		
 		#sending request
 		r = requests.post(apio_url_exception, 
